@@ -641,6 +641,7 @@ fi
 PLATFORM=ubuntu12_32
 PLATFORM32=ubuntu12_32
 PLATFORM64=ubuntu12_64
+STEAMRT64=steamrt64
 STEAMEXEPATH=$PLATFORM/$STEAMEXE
 
 # common variables for later
@@ -681,14 +682,6 @@ if [ "$INITIAL_LAUNCH" ]; then
 		STEAMSCRIPT="/usr/bin/`detect_package`"
 	fi
 
-	# Install any additional dependencies
-	if [ -z "$STEAMOS" ] && [ -z "${WSL_DISTRO_NAME:-}" ]; then
-		STEAMDEPS="`dirname $STEAMSCRIPT`/`detect_package`deps"
-		if [ -f "$STEAMDEPS" -a -f "$STEAMROOT/steamdeps.txt" ]; then
-			"$STEAMDEPS" $STEAMROOT/steamdeps.txt
-		fi
-	fi
-
 	# Create symbolic links for the Steam API
 	if [ ! -e "$STEAMCONFIG" ]; then
 		mkdir "$STEAMCONFIG"
@@ -824,47 +817,36 @@ if [ -n "$log_opened" ]; then
 	set -- -srt-logger-opened "$@"
 fi
 
-# Expand and check the sniper runtime early if present
-supervisor="${STEAM_RUNTIME_SCOUT}/amd64/usr/bin/steam-runtime-supervisor"
-if [ -x "$supervisor" ]; then
-    log "Using supervisor $supervisor"
-    common_lock_options=( \
-        --exit-with-parent \
-        --subreaper \
-        --terminate-idle-timeout=1 \
-        --terminate-timeout=5 \
-        --lock-create \
-        --lock-verbose \
-        --lock-file "$STEAMROOT/$PLATFORM64/steam-runtime-sniper.lock" \
-    )
+# Clean up remnants of the sniper runtime, now replaced by steamrt3c (steamrt64)
+rm -fr "${STEAMROOT}/ubuntu12_64/steam-runtime-sniper/"
+rm -f "${STEAMROOT}/ubuntu12_64/steam-runtime-sniper.lock"
+rm -f "${STEAMROOT}/ubuntu12_64/steam-runtime-steamrt.lock"
 
-	# Because options are parsed in order, --lock-exclusive needs to be
-	# specified before --lock-file
-	exclusive_lock=( "$supervisor" --lock-exclusive "${common_lock_options[@]}" -- )
-else
-	# Unexpected - we unpack scout unconditionally
-	log "Unable to find $supervisor"
-	exit 255
-fi
-
-if [ -f "$STEAMROOT/$PLATFORM64/steam-runtime-sniper.sh" ]; then
+function setup_steamrt_override()
+{
 	status=0
-	"${exclusive_lock[@]}" \
-	"$STEAMROOT/$PLATFORM64/steam-runtime-sniper.sh" \
-	--unpack-dir="$STEAMROOT/$PLATFORM64" \
-	--runtime=steam-runtime-sniper > /dev/null || status="$?"
+	"$STEAMROOT/$STEAMRT64/steam-runtime-steamrt.sh" \
+	--unpack-dir="$STEAMROOT/$STEAMRT64" \
+	--runtime=steam-runtime-steamrt > /dev/null || status="$?"
 	case "$status" in
 		(0)
 			# Unpacked successfully
 			;;
-		(125)
-			log "Could not acquire lock - steam may be running already, continue."
-			;;
 		(*)
-			log "Encountered a problem expanding the sniper runtime, forcing extended file verification."
+			log "Encountered a problem expanding the steamrt runtime, forcing extended file verification."
 			set -- "$@" "-verifyfiles"
 			;;
 	esac
+}
+
+# In dev environments we allow overriding the steam runtime with a local payload
+# To use an override runtime:
+#  * Place the runtime files in the relevant platform folder
+#  * Inhibit the bootstrapper via Steam.cfg (otherwise the bootstrapper will overwrite it)
+if [ -n "${STEAM_RUNTIME_STEAMRT-}" ]; then
+	log "Using custom runtime $STEAM_RUNTIME_STEAMRT for steamwebhelper (this is unsupported)"
+elif [[ -f "$STEAMROOT/$STEAMRT64/steam-runtime-steamrt.tar.xz" ]]; then
+	setup_steamrt_override
 fi
 
 # prepend our lib path to LD_LIBRARY_PATH
